=========
WordStart
=========


.. image:: https://img.shields.io/pypi/v/wordstart.svg
        :target: https://pypi.python.org/pypi/wordstart

.. image:: https://img.shields.io/travis/mmlmpa/wordstart.svg
        :target: https://travis-ci.org/mmlmpa/wordstart

.. image:: https://readthedocs.org/projects/wordstart/badge/?version=latest
        :target: https://wordstart.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Prints the words in the given string that start with the given letter


* Free software: MIT license
* Documentation: https://wordstart.readthedocs.io.


Features
--------

* Still TODO. Nothing to add here yet. It is a very simple package.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
